Rapports | OiRA

Thèmes

# Rapports

Vous pouvez utiliser un rapport pour:

- fournir des preuves aux autorités de contrôle;
- transmettre l’information aux personnes concernées (travailleurs, représentants de la sécurité, employeurs, experts en SST, etc.);
- contrôler et évaluer si les mesures nécessaires ont été introduites;
- enregistrer les révisions éventuelles en cas d’évolution des circonstances (nouvelles machines/travailleurs, ou suite aux conclusions d’une enquête sur un accident, etc.).

Vous pouvez sauvegarder le rapport sur votre ordinateur et l’imprimer. Vous pouvez aussi le modifier ou y ajouter des informations supplémentaires. Attention: toute modification apportée à un rapport que vous avez téléchargé ne sera PAS enregistrée dans l’outil OiRA.

## Choix du rapport

Il existe différents types de rapport disponibles selon les objectifs visés. L’offre de rapports disponibles dépend des choix de configuration faits par le partenaire national/développeur d’outils OiRA.

Les rapports disponibles

### Rapport complet

Format: Word / Office Open XML (.docx). Possibilité de modification après le téléchargement.

Fournit: toutes les informations et les données que vous avez saisies lors du processus d’évaluation des risques.

À utiliser pour: apporter la preuve de l’évaluation des risques aux autorités de contrôle (par exemple, l’inspection du travail).

### Plan d’action

Format: Excel / Office Open XML (.xlsx). Possibilité de modification après le téléchargement.

Fournit: des informations sur toutes les mesures que vous avez choisi de mettre en œuvre.

À utiliser pour:

- suivre activement la mise en œuvre des mesures que vous avez choisies;
- gérer les problèmes/risques sur votre lieu de travail (tâches particulières, expertise, responsabilités, délais).

### Vue d’ensemble des risques

Format: Portable Document Format (.pdf). Pas de modification possible après le téléchargement.

Fournit: une vue d’ensemble des risques identifiés

À utiliser pour:

- obtenir un aperçu rapide de la situation en matière de risques sur votre lieu de travail;
- transmettre l’information aux personnes concernées;
- contrôler si les risques/les mesures sont traités de manière appropriée.

### Vue d’ensemble des mesures

Format: Portable Document Format (.pdf). Pas de modification possible après le téléchargement.

Fournit: une vue d’ensemble des mesures à mettre en œuvre.

À utiliser pour:

- obtenir un aperçu rapide de l’état d’avancement des mesures que vous avez décidé de mettre en œuvre;
- transmettre l’information aux personnes concernées;
- contrôler si les risques/les mesures sont traités de manière appropriée.

Scroll to top Load toolbar…
Back

## 4-reports.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More